@@ -3,21 +3,18 @@ package DBIx::DataModel::Schema::ResultAs;
 #----------------------------------------------------------------------
 use strict;
 use warnings;
+use DBIx::DataModel::Meta::Utils qw/define_abstract_methods/;
 
 use Carp::Clan       qw[^(DBIx::DataModel::|SQL::Abstract)];
 
+define_abstract_methods(__PACKAGE__, qw/get_result/);
+
 sub new {
   my $class = shift;
 
   return bless {@_}, $class;
 }
 
-sub get_result {
-  my $self  = shift;
-  my $class = ref $self || $self;
-  croak "$class should implement a get_result() method";
-}
-
 1;
 
 __END__
@@ -39,10 +36,6 @@ Subclasses should implement
 
 =over
 
-=item C<new()>
-
-The constructor
-
 =item C<get_result()>
 
   $result = $subclass->new(...)->get_result($statement);
